@@ -1,6 +1,8 @@
 from nestedtext import load as ntload
 from plumbum.cli import Application, ExistingFile, SwitchAttr
 from plumbum.colors import blue, green, magenta, yellow
+from rich import inspect as _rich_inspect
+from rich.console import Console as RichConsole
 
 from . import __version__
 from .dumpers import (
@@ -8,12 +10,11 @@ from .dumpers import (
     dump_nestedtext_to_yaml, dump_toml_to_nestedtext, dump_yaml_to_nestedtext
 )
 
-try:
-    from rich.traceback import install as rich_tb_install
-except ImportError:
-    pass
-else:
-    rich_tb_install()
+RICH = RichConsole(stderr=True)
+
+
+def rich_inspect(*args, **kwargs):
+    return _rich_inspect(*args, **kwargs, console=RICH)
 
 
 class ColorApp(Application):
@@ -91,18 +92,22 @@ class NestedTextToJSON(NestedTextToTypedFormat, NestedTextToTypedFormatSupportNu
     """
 
     def main(self, *input_files: ExistingFile):
-        for schema_file in self.schema_files:
-            schema = ntload(schema_file)
-            self.null_paths = [*schema.get('null', ()), *self.null_paths]
-            self.bool_paths = [*schema.get('boolean', ()), *self.bool_paths]
-            self.num_paths = [*schema.get('number', ()), *self.num_paths]
+        try:
+            for schema_file in self.schema_files:
+                schema = ntload(schema_file)
+                self.null_paths = [*schema.get('null', ()), *self.null_paths]
+                self.bool_paths = [*schema.get('boolean', ()), *self.bool_paths]
+                self.num_paths = [*schema.get('number', ()), *self.num_paths]
 
-        dump_nestedtext_to_json(
-            *input_files,
-            bool_paths=self.bool_paths,
-            null_paths=self.null_paths,
-            num_paths=self.num_paths,
-        )
+            dump_nestedtext_to_json(
+                *input_files,
+                bool_paths=self.bool_paths,
+                null_paths=self.null_paths,
+                num_paths=self.num_paths,
+            )
+        except Exception as e:
+            rich_inspect(e)
+            return 1
 
 
 class NestedTextToYAML(
@@ -124,20 +129,24 @@ class NestedTextToYAML(
     """
 
     def main(self, *input_files: ExistingFile):
-        for schema_file in self.schema_files:
-            schema = ntload(schema_file)
-            self.null_paths = [*schema.get('null', ()), *self.null_paths]
-            self.bool_paths = [*schema.get('boolean', ()), *self.bool_paths]
-            self.num_paths = [*schema.get('number', ()), *self.num_paths]
-            self.date_paths = [*schema.get('date', ()), *self.date_paths]
+        try:
+            for schema_file in self.schema_files:
+                schema = ntload(schema_file)
+                self.null_paths = [*schema.get('null', ()), *self.null_paths]
+                self.bool_paths = [*schema.get('boolean', ()), *self.bool_paths]
+                self.num_paths = [*schema.get('number', ()), *self.num_paths]
+                self.date_paths = [*schema.get('date', ()), *self.date_paths]
 
-        dump_nestedtext_to_yaml(
-            *input_files,
-            bool_paths=self.bool_paths,
-            null_paths=self.null_paths,
-            num_paths=self.num_paths,
-            date_paths=self.date_paths,
-        )
+            dump_nestedtext_to_yaml(
+                *input_files,
+                bool_paths=self.bool_paths,
+                null_paths=self.null_paths,
+                num_paths=self.num_paths,
+                date_paths=self.date_paths,
+            )
+        except Exception as e:
+            rich_inspect(e)
+            return 1
 
 
 class NestedTextToTOML(NestedTextToTypedFormat, NestedTextToTypedFormatSupportDate):
@@ -157,18 +166,22 @@ class NestedTextToTOML(NestedTextToTypedFormat, NestedTextToTypedFormatSupportDa
     """
 
     def main(self, *input_files: ExistingFile):
-        for schema_file in self.schema_files:
-            schema = ntload(schema_file)
-            self.bool_paths = [*schema.get('boolean', ()), *self.bool_paths]
-            self.num_paths = [*schema.get('number', ()), *self.num_paths]
-            self.date_paths = [*schema.get('date', ()), *self.date_paths]
+        try:
+            for schema_file in self.schema_files:
+                schema = ntload(schema_file)
+                self.bool_paths = [*schema.get('boolean', ()), *self.bool_paths]
+                self.num_paths = [*schema.get('number', ()), *self.num_paths]
+                self.date_paths = [*schema.get('date', ()), *self.date_paths]
 
-        dump_nestedtext_to_toml(
-            *input_files,
-            bool_paths=self.bool_paths,
-            num_paths=self.num_paths,
-            date_paths=self.date_paths,
-        )
+            dump_nestedtext_to_toml(
+                *input_files,
+                bool_paths=self.bool_paths,
+                num_paths=self.num_paths,
+                date_paths=self.date_paths,
+            )
+        except Exception as e:
+            rich_inspect(e)
+            return 1
 
 
 class JSONToNestedText(ColorApp):
@@ -184,7 +197,11 @@ class JSONToNestedText(ColorApp):
     # --make-schema ? --gen-schema ? --only-schema ? separate command?
 
     def main(self, *input_files: ExistingFile):
-        dump_json_to_nestedtext(*input_files)
+        try:
+            dump_json_to_nestedtext(*input_files)
+        except Exception as e:
+            rich_inspect(e)
+            return 1
 
 
 class YAMLToNestedText(ColorApp):
@@ -198,7 +215,11 @@ class YAMLToNestedText(ColorApp):
     """
 
     def main(self, *input_files: ExistingFile):
-        dump_yaml_to_nestedtext(*input_files)
+        try:
+            dump_yaml_to_nestedtext(*input_files)
+        except Exception as e:
+            rich_inspect(e)
+            return 1
 
 
 class TOMLToNestedText(ColorApp):
@@ -212,4 +233,8 @@ class TOMLToNestedText(ColorApp):
     """
 
     def main(self, *input_files: ExistingFile):
-        dump_toml_to_nestedtext(*input_files)
+        try:
+            dump_toml_to_nestedtext(*input_files)
+        except Exception as e:
+            rich_inspect(e)
+            return 1
